@@ -9,11 +9,11 @@
     };
     int packobjc[] = {
         102,
-        191,
+        193,
         106,
         88,
-        500,
-        210
+        502,
+        218
     };
     const char *packobj[] = {
         "AirPassengers",
@@ -157,6 +157,7 @@
         "aspell_package_Rd_files",
         "aspell_package_vignettes",
         "aspell_write_personal_dictionary_file",
+        "assignInMyNamespace",
         "assignInNamespace",
         "available.packages",
         "bibentry",
@@ -212,6 +213,7 @@
         "getSrcref",
         "getTxtProgressBar",
         "glob2rx",
+        "globalVariables",
         "head",
         "head.matrix",
         "help",
@@ -783,6 +785,7 @@
         "offset",
         "oneway.test",
         "optim",
+        "optimHess",
         "optimise",
         "optimize",
         "order.dendrogram",
@@ -894,6 +897,7 @@
         "qweibull",
         "qwilcox",
         "r2dtable",
+        "rWishart",
         "rbeta",
         "rbinom",
         "rcauchy",
@@ -1060,7 +1064,9 @@
         "elNamed<-",
         "empty.dump",
         "emptyMethodsList",
+        "evalOnLoad",
         "evalSource",
+        "evalqOnLoad",
         "existsFunction",
         "existsMethod",
         "extends",
@@ -1091,6 +1097,7 @@
         "getGenerics",
         "getGroup",
         "getGroupMembers",
+        "getLoadActions",
         "getMethod",
         "getMethods",
         "getMethodsForDispatch",
@@ -1104,6 +1111,7 @@
         "getValidity",
         "getVirtual",
         "hasArg",
+        "hasLoadAction",
         "hasMethod",
         "hasMethods",
         "implicitGeneric",
@@ -1111,6 +1119,7 @@
         "initFieldArgs",
         "initRefFields",
         "initialize",
+        "insertClassMethods",
         "insertMethod",
         "insertSource",
         "is",
@@ -1124,6 +1133,7 @@
         "isSealedMethod",
         "isVirtualClass",
         "isXS3Class",
+        "kronecker",
         "languageEl",
         "languageEl<-",
         "linearizeMlist",
@@ -1182,6 +1192,8 @@
         "setGenericImplicit",
         "setGroupGeneric",
         "setIs",
+        "setLoadAction",
+        "setLoadActions",
         "setMethod",
         "setOldClass",
         "setPackageName",
